import request from '@/config/axios'

// 诊室和诊疗床 VO
export interface RoomVO {
  id: number  //
  roomId: number // 诊室编号
  roomName: string // 诊室名称
  bedNo: string // 诊疗床编号
  status: number //开诊状态
  doctor_name: string //医生名
}

// 诊室和诊疗床 API
export const RoomApi = {
  // 查询诊室和诊疗床分页
  getRoomPage: async (params: any) => {
    return await request.get({ url: `/clinic/room/page`, params })
  },

  // 查询诊室和诊疗床详情
  getRoom: async (id: number) => {
    return await request.get({ url: `/clinic/room/get?id=` + id })
  },

  // 新增诊室和诊疗床
  createRoom: async (data: RoomVO) => {
    return await request.post({ url: `/clinic/room/create`, data })
  },

  // 修改诊室和诊疗床
  updateRoom: async (data: RoomVO) => {
    return await request.put({ url: `/clinic/room/update`, data })
  },

  // 删除诊室和诊疗床
  deleteRoom: async (id: number) => {
    return await request.delete({ url: `/clinic/room/delete?id=` + id })
  },

  // 导出诊室和诊疗床 Excel
  exportRoom: async (params) => {
    return await request.download({ url: `/clinic/room/export-excel`, params })
  },

  // 获取部门精简信息列表 ECG 子部门
  getSimpleRoomList: async () => {
    return await request.get({ url: `/clinic/room/simple-list` })
  },

  // 获取诊室精简信息列表，用于医生选择登录的诊室
  getOnstageBedMap: async () => {
    return await request.get({ url: `/clinic/room/list-simple-room` })
  },


  // 获取诊床Map
  getAllBedMap: async () => {
    return await request.get({ url: `/clinic/room/list-all-bed` })
  }
}
